# Generated by Django 4.2.7 on 2023-12-04 22:19

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_locator", "0034_alter_historicalsubjectlocator_device_created_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="subjectlocator",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Subject Locator",
                "verbose_name_plural": "Subject Locators",
            },
        ),
        migrations.AddField(
            model_name="historicalsubjectlocator",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectlocator",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="subjectlocator",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="subjectlocator",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddIndex(
            model_name="subjectlocator",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="edc_locator_action__77234b_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjectlocator",
            index=models.Index(
                fields=["modified", "created"], name="edc_locator_modifie_25c089_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectlocator",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="edc_locator_user_mo_65bf36_idx",
            ),
        ),
    ]
